diff --git a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.C b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.C
index f380512362f9a8bea97480d42faef829a0c7fb7b..8e0d4f3581a7fd4ae504a68f796781dec9484027 100644
--- a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.C
+++ b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.C
@@ -34,7 +34,7 @@ Foam::tetIndices::tetIndices()
     faceBasePtI_(-1),
     facePtAI_(-1),
     facePtBI_(-1),
-    tetPtI_(-1)
+    tetPti_(-1)
 {}
 
 
@@ -53,7 +53,7 @@ Foam::tetIndices::tetIndices
     faceBasePtI_(faceBasePtI),
     facePtAI_(facePtAI),
     facePtBI_(facePtBI),
-    tetPtI_(tetPtI)
+    tetPti_(tetPtI)
 {}
 
 
@@ -70,7 +70,7 @@ Foam::tetIndices::tetIndices
     faceBasePtI_(-1),
     facePtAI_(-1),
     facePtBI_(-1),
-    tetPtI_(tetPtI)
+    tetPti_(tetPtI)
 {
     const faceList& pFaces = mesh.faces();
     const labelList& pOwner = mesh.faceOwner();
@@ -81,7 +81,7 @@ Foam::tetIndices::tetIndices
 
     faceBasePtI_ = mesh.tetBasePtIs()[facei_];
 
-    label facePtI = (tetPtI_ + faceBasePtI_) % f.size();
+    label facePtI = (tetPti_ + faceBasePtI_) % f.size();
     label otherFacePtI = f.fcIndex(facePtI);
 
     if (own)
diff --git a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.H b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.H
index 9c4bdcad5bc8f61de78c5e5f92cf5b7fa7c70316..0c80210e636e62b6a25ee1335ea2efc7ae411d2f 100644
--- a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.H
+++ b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndices.H
@@ -104,7 +104,7 @@ class tetIndices
 
     //- Point on the face, *relative to the base point*, which
     //  characterises this tet on the face.
-    label tetPtI_;
+    label tetPti_;
 
 
 public:
diff --git a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndicesI.H b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndicesI.H
index 7a30eea0999f161053c84d2094e351ad23d7aea4..1024595e4f3ed0dab2433663c60d42eb6baed4d3 100644
--- a/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndicesI.H
+++ b/src/OpenFOAM/meshes/polyMesh/polyMeshTetDecomposition/tetIndicesI.H
@@ -23,8 +23,6 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
 Foam::label Foam::tetIndices::cell() const
@@ -59,7 +57,7 @@ Foam::label Foam::tetIndices::facePtB() const
 
 Foam::label Foam::tetIndices::tetPt() const
 {
-    return tetPtI_;
+    return tetPti_;
 }
 
 
@@ -185,7 +183,7 @@ Foam::label& Foam::tetIndices::facePtB()
 
 Foam::label& Foam::tetIndices::tetPt()
 {
-    return tetPtI_;
+    return tetPti_;
 }
 
 
diff --git a/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.C b/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.C
index 02a900a722c3e0f7d059068a9cd902ec6da5be3d..6da1c1aa8e8883c7b3ae3bd6b4e4523a20ab58c7 100644
--- a/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.C
+++ b/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.C
@@ -468,7 +468,7 @@ void Foam::DSMCCloud<ParcelType>::addNewParcel
     const scalar Ei,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId
 )
 {
@@ -480,7 +480,7 @@ void Foam::DSMCCloud<ParcelType>::addNewParcel
         Ei,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId
     );
 
diff --git a/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.H b/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.H
index 6c4a936ac7aea8cd96927ddb331fc78898c2059a..d7ea2be9b4150d2e310b4bf3e67a1c5456a8900e 100644
--- a/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.H
+++ b/src/lagrangian/DSMC/clouds/Templates/DSMCCloud/DSMCCloud.H
@@ -455,7 +455,7 @@ public:
                 const scalar Ei,
                 const label celli,
                 const label tetFacei,
-                const label tetPtI,
+                const label tetPti,
                 const label typeId
             );
 
diff --git a/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcel.H b/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcel.H
index c9b81509d7419f609e85f0ba5e73e784018507e5..0435546342e03406ac3fda3dbe16903d6c506808 100644
--- a/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcel.H
+++ b/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcel.H
@@ -183,7 +183,7 @@ public:
             const scalar Ei,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId
         );
 
diff --git a/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcelI.H b/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcelI.H
index fb41a6cee331b2ea28ada801c4e75604c1291b39..5fb82c5cdad57bac557e87d555275b67f5d70f39 100644
--- a/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcelI.H
+++ b/src/lagrangian/DSMC/parcels/Templates/DSMCParcel/DSMCParcelI.H
@@ -60,11 +60,11 @@ inline Foam::DSMCParcel<ParcelType>::DSMCParcel
     const scalar Ei,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId
 )
 :
-    ParcelType(mesh, position, celli, tetFacei, tetPtI),
+    ParcelType(mesh, position, celli, tetFacei, tetPti),
     U_(U),
     Ei_(Ei),
     typeId_(typeId)
diff --git a/src/lagrangian/DSMC/parcels/derived/dsmcParcel/dsmcParcel.C b/src/lagrangian/DSMC/parcels/derived/dsmcParcel/dsmcParcel.C
index ea58c2f59b9caeec38c10e6510e66fc157f0595b..e0ec951fccd34fc1dbab708b1cde60cdf0b4b414 100644
--- a/src/lagrangian/DSMC/parcels/derived/dsmcParcel/dsmcParcel.C
+++ b/src/lagrangian/DSMC/parcels/derived/dsmcParcel/dsmcParcel.C
@@ -44,7 +44,7 @@ Foam::dsmcParcel::dsmcParcel
     const scalar Ei,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId
 )
 :
@@ -56,7 +56,7 @@ Foam::dsmcParcel::dsmcParcel
         Ei,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId
     )
 {}
diff --git a/src/lagrangian/basic/indexedParticle/indexedParticle.H b/src/lagrangian/basic/indexedParticle/indexedParticle.H
index 9c3a017a24b1048f429c2b5e5dcc6a247f604a06..75ed0783e4284b142dd1e049935ebdaf5a73461e 100644
--- a/src/lagrangian/basic/indexedParticle/indexedParticle.H
+++ b/src/lagrangian/basic/indexedParticle/indexedParticle.H
@@ -68,11 +68,11 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label index = 0
         )
         :
-            particle(mesh, position, celli, tetFacei, tetPtI),
+            particle(mesh, position, celli, tetFacei, tetPti),
             index_(index)
         {}
 
diff --git a/src/lagrangian/basic/particle/particle.C b/src/lagrangian/basic/particle/particle.C
index fa1fc78420fb5f7b1427a5624fcac4c93c1aed4e..88de1e7dda789e9adc773d87f9fa9b17bc7e6af2 100644
--- a/src/lagrangian/basic/particle/particle.C
+++ b/src/lagrangian/basic/particle/particle.C
@@ -50,7 +50,7 @@ Foam::particle::particle
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
     mesh_(mesh),
@@ -59,7 +59,7 @@ Foam::particle::particle
     facei_(-1),
     stepFraction_(0.0),
     tetFacei_(tetFacei),
-    tetPtI_(tetPtI),
+    tetPti_(tetPti),
     origProc_(Pstream::myProcNo()),
     origId_(getNewParticleID())
 {}
@@ -79,7 +79,7 @@ Foam::particle::particle
     facei_(-1),
     stepFraction_(0.0),
     tetFacei_(-1),
-    tetPtI_(-1),
+    tetPti_(-1),
     origProc_(Pstream::myProcNo()),
     origId_(getNewParticleID())
 {
@@ -98,7 +98,7 @@ Foam::particle::particle(const particle& p)
     facei_(p.facei_),
     stepFraction_(p.stepFraction_),
     tetFacei_(p.tetFacei_),
-    tetPtI_(p.tetPtI_),
+    tetPti_(p.tetPti_),
     origProc_(p.origProc_),
     origId_(p.origId_)
 {}
@@ -112,7 +112,7 @@ Foam::particle::particle(const particle& p, const polyMesh& mesh)
     facei_(p.facei_),
     stepFraction_(p.stepFraction_),
     tetFacei_(p.tetFacei_),
-    tetPtI_(p.tetPtI_),
+    tetPti_(p.tetPti_),
     origProc_(p.origProc_),
     origId_(p.origId_)
 {}
diff --git a/src/lagrangian/basic/particle/particleIO.C b/src/lagrangian/basic/particle/particleIO.C
index 1c4b2bf9ad69d19d5e7535c6229279fdc60a8a32..6dbb45c7b5c5a9483c1b767e71ad1a04948053fe 100644
--- a/src/lagrangian/basic/particle/particleIO.C
+++ b/src/lagrangian/basic/particle/particleIO.C
@@ -51,7 +51,7 @@ Foam::particle::particle(const polyMesh& mesh, Istream& is, bool readFields)
     facei_(-1),
     stepFraction_(0.0),
     tetFacei_(-1),
-    tetPtI_(-1),
+    tetPti_(-1),
     origProc_(Pstream::myProcNo()),
     origId_(-1)
 {
@@ -64,7 +64,7 @@ Foam::particle::particle(const polyMesh& mesh, Istream& is, bool readFields)
             is  >> facei_
                 >> stepFraction_
                 >> tetFacei_
-                >> tetPtI_
+                >> tetPti_
                 >> origProc_
                 >> origId_;
         }
@@ -111,7 +111,7 @@ Foam::Ostream& Foam::operator<<(Ostream& os, const particle& p)
             << token::SPACE << p.facei_
             << token::SPACE << p.stepFraction_
             << token::SPACE << p.tetFacei_
-            << token::SPACE << p.tetPtI_
+            << token::SPACE << p.tetPti_
             << token::SPACE << p.origProc_
             << token::SPACE << p.origId_;
     }
diff --git a/src/lagrangian/basic/passiveParticle/passiveParticle.H b/src/lagrangian/basic/passiveParticle/passiveParticle.H
index 572692566d7de4ad54c0e253b682adfda972c31e..1c8f7be0f7fff6b361c18deebc252037a9836c95 100644
--- a/src/lagrangian/basic/passiveParticle/passiveParticle.H
+++ b/src/lagrangian/basic/passiveParticle/passiveParticle.H
@@ -64,10 +64,10 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         )
         :
-            particle(mesh, position, celli, tetFacei, tetPtI)
+            particle(mesh, position, celli, tetFacei, tetPti)
         {}
 
         //- Construct from components, with searching for tetFace and
diff --git a/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcel.H b/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcel.H
index b581ef6eb9df3bc27a39e44b83d4402d0368263a..113f4ac51bdb0dfeadad3e34316b9f02b43e028d 100644
--- a/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcel.H
@@ -171,7 +171,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -181,7 +181,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcelI.H b/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcelI.H
index a08b546441c9da9c6c60a54c0980e74609c4fbd5..c40c4e5d54e6530cf35dfedb84078bfed2b66fb3 100644
--- a/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/CollidingParcel/CollidingParcelI.H
@@ -66,10 +66,10 @@ inline Foam::CollidingParcel<ParcelType>::CollidingParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(owner, position, celli, tetFacei, tetPtI),
+    ParcelType(owner, position, celli, tetFacei, tetPti),
     f_(Zero),
     angularMomentum_(Zero),
     torque_(Zero),
@@ -84,7 +84,7 @@ inline Foam::CollidingParcel<ParcelType>::CollidingParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -102,7 +102,7 @@ inline Foam::CollidingParcel<ParcelType>::CollidingParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcel.H b/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcel.H
index f5e57a39282ac3c6d0ad19c79e373afa0767c6b1..f3ebe37a843261b6a9588a8485c11b6da1e4c6fb 100644
--- a/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcel.H
@@ -328,7 +328,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -338,7 +338,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcelI.H b/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcelI.H
index 5f71e7b655df97a40ae246771064b43dc551218c..42e6d1440907623dd6e9502bec1c504633ec042d 100644
--- a/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/KinematicParcel/KinematicParcelI.H
@@ -76,10 +76,10 @@ inline Foam::KinematicParcel<ParcelType>::KinematicParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(owner, position, celli, tetFacei, tetPtI),
+    ParcelType(owner, position, celli, tetFacei, tetPti),
     active_(true),
     typeId_(-1),
     nParticle_(0),
@@ -103,7 +103,7 @@ inline Foam::KinematicParcel<ParcelType>::KinematicParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -112,7 +112,7 @@ inline Foam::KinematicParcel<ParcelType>::KinematicParcel
     const constantProperties& constProps
 )
 :
-    ParcelType(owner, position, celli, tetFacei, tetPtI),
+    ParcelType(owner, position, celli, tetFacei, tetPti),
     active_(true),
     typeId_(typeId),
     nParticle_(nParticle0),
diff --git a/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcel.H b/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcel.H
index 313bd60025c41a5c76b9c83820b724db956fc5a9..c02d97e1e0ce75e22fa38eb730a5eba657235bc6 100644
--- a/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcel.H
@@ -189,7 +189,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -199,7 +199,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcelI.H b/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcelI.H
index 3ee0b680544413e4b88abd854732e27bd87456cb..1af5110019e76e153ba6e9d04f2a6bfce14cf683 100644
--- a/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/MPPICParcel/MPPICParcelI.H
@@ -32,10 +32,10 @@ inline Foam::MPPICParcel<ParcelType>::MPPICParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(owner, position, celli, tetFacei, tetPtI),
+    ParcelType(owner, position, celli, tetFacei, tetPti),
     UCorrect_(Zero)
 {}
 
@@ -47,7 +47,7 @@ inline Foam::MPPICParcel<ParcelType>::MPPICParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -63,7 +63,7 @@ inline Foam::MPPICParcel<ParcelType>::MPPICParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcel.H b/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcel.H
index 2f76f9ef7cb7478893fdf0a6f22b8086f3786b6e..417f085e713f13d17ded7cb7e3508fae9e7d6db2 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcel.H
@@ -278,7 +278,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
 
@@ -289,7 +289,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcelI.H b/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcelI.H
index 005cafb6322ed7041475ed7ad7172078fd68e4f7..c64e29b262fc9737d9364982f5c2e50cfcee969b 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ReactingMultiphaseParcel/ReactingMultiphaseParcelI.H
@@ -71,10 +71,10 @@ inline Foam::ReactingMultiphaseParcel<ParcelType>::ReactingMultiphaseParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(mesh, position, celli, tetFacei, tetPtI),
+    ParcelType(mesh, position, celli, tetFacei, tetPti),
     YGas_(0),
     YLiquid_(0),
     YSolid_(0),
@@ -89,7 +89,7 @@ inline Foam::ReactingMultiphaseParcel<ParcelType>::ReactingMultiphaseParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -111,7 +111,7 @@ inline Foam::ReactingMultiphaseParcel<ParcelType>::ReactingMultiphaseParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcel.H b/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcel.H
index d48fa45e944da067e60598d4161dda7d887681be..81db6586f3cdfc145c7e8b70132b4e9fbe63c6e3 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcel.H
@@ -232,7 +232,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -242,7 +242,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcelI.H b/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcelI.H
index 78fea81bc53daef38dbe0f2f1c3af70152a6ac73..a6359c400626e4cff76b588fb8ea56f67c7319b5 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ReactingParcel/ReactingParcelI.H
@@ -66,10 +66,10 @@ inline Foam::ReactingParcel<ParcelType>::ReactingParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(mesh, position, celli, tetFacei, tetPtI),
+    ParcelType(mesh, position, celli, tetFacei, tetPti),
     mass0_(0.0),
     Y_(0),
     pc_(0.0)
@@ -83,7 +83,7 @@ inline Foam::ReactingParcel<ParcelType>::ReactingParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -102,7 +102,7 @@ inline Foam::ReactingParcel<ParcelType>::ReactingParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcel.H b/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcel.H
index fd8af64a7b8f22c7511488a742bef046c3bdfb17..84b6e9c5e66fd37ba411ec62605671ca0051c0fb 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcel.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcel.H
@@ -288,7 +288,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -298,7 +298,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcelI.H b/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcelI.H
index b4e80ad19a927555585697fca4d6a2fd1e698a6a..9b2f365b4474c9036321e27b1d257ed5478fe03a 100644
--- a/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcelI.H
+++ b/src/lagrangian/intermediate/parcels/Templates/ThermoParcel/ThermoParcelI.H
@@ -77,10 +77,10 @@ inline Foam::ThermoParcel<ParcelType>::ThermoParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(mesh, position, celli, tetFacei, tetPtI),
+    ParcelType(mesh, position, celli, tetFacei, tetPti),
     T_(0.0),
     Cp_(0.0),
     Tc_(0.0),
@@ -95,7 +95,7 @@ inline Foam::ThermoParcel<ParcelType>::ThermoParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -113,7 +113,7 @@ inline Foam::ThermoParcel<ParcelType>::ThermoParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.C
index 8336f8c88faee291935f9c98985295ecb07fdf9e..07ec1e9b26da7d5a80633d9a5b46b71e86ec3b39 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.C
@@ -320,13 +320,13 @@ void Foam::CellZoneInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     position = positions_[parcelI];
     cellOwner = injectorCells_[parcelI];
     tetFacei = injectorTetFaces_[parcelI];
-    tetPtI = injectorTetPts_[parcelI];
+    tetPti = injectorTetPts_[parcelI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.H
index 9213037ee9f4765d5dada4d75fe6a87782034501..be21d3f5ece02ce0898e96685f0d1176a7b2dbe7 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/CellZoneInjection/CellZoneInjection.H
@@ -157,7 +157,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.C
index 8e979312267df9dce59eb86f3488fd12ac7f3b30..88c30c6e0e2792522b8bbba4571c67226ae5db90 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.C
@@ -241,7 +241,7 @@ void Foam::ConeInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     const label i = parcelI % positionAxis_.size();
@@ -249,7 +249,7 @@ void Foam::ConeInjection<CloudType>::setPositionAndCell
     position = positionAxis_[i].first();
     cellOwner = injectorCells_[i];
     tetFacei = injectorTetFaces_[i];
-    tetPtI = injectorTetPts_[i];
+    tetPti = injectorTetPts_[i];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.H
index a482be6af8ac30ddb02ea040a7cd92e384695f57..9cd2a829f558ec63a33097edde1c20e75fc89961 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeInjection/ConeInjection.H
@@ -172,7 +172,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.C
index 392f901f463de8eb5aed2e2691b876397549a983..30e9540c9fd8406c44949a0ca3b7b3e676941f81 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.C
@@ -49,7 +49,7 @@ void Foam::ConeNozzleInjection<CloudType>::setInjectionMethod()
         (
             injectorCell_,
             tetFacei_,
-            tetPtI_,
+            tetPti_,
             position_,
             false
         );
@@ -111,7 +111,7 @@ Foam::ConeNozzleInjection<CloudType>::ConeNozzleInjection
     position_(this->coeffDict().lookup("position")),
     injectorCell_(-1),
     tetFacei_(-1),
-    tetPtI_(-1),
+    tetPti_(-1),
     direction_(this->coeffDict().lookup("direction")),
     parcelsPerSecond_
     (
@@ -215,7 +215,7 @@ Foam::ConeNozzleInjection<CloudType>::ConeNozzleInjection
     position_(im.position_),
     injectorCell_(im.injectorCell_),
     tetFacei_(im.tetFacei_),
-    tetPtI_(im.tetPtI_),
+    tetPti_(im.tetPti_),
     direction_(im.direction_),
     parcelsPerSecond_(im.parcelsPerSecond_),
     flowRateProfile_(im.flowRateProfile_),
@@ -252,7 +252,7 @@ void Foam::ConeNozzleInjection<CloudType>::updateMesh()
             (
                 injectorCell_,
                 tetFacei_,
-                tetPtI_,
+                tetPti_,
                 position_
             );
         }
@@ -316,7 +316,7 @@ void Foam::ConeNozzleInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     cachedRandom& rndGen = this->owner().rndGen();
@@ -331,7 +331,7 @@ void Foam::ConeNozzleInjection<CloudType>::setPositionAndCell
             position = position_;
             cellOwner = injectorCell_;
             tetFacei = tetFacei_;
-            tetPtI = tetPtI_;
+            tetPti = tetPti_;
 
             break;
         }
@@ -346,7 +346,7 @@ void Foam::ConeNozzleInjection<CloudType>::setPositionAndCell
             (
                 cellOwner,
                 tetFacei,
-                tetPtI,
+                tetPti,
                 position,
                 false
             );
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.H
index 5d7e34f11800e9a90f3349cadc2d86e759803055..1ccce9208e8978c40ee33daf7d91f5c3fd089d3a 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ConeNozzleInjection/ConeNozzleInjection.H
@@ -131,7 +131,7 @@ private:
         label tetFacei_;
 
         //- Index of tet point for injector cell
-        label tetPtI_;
+        label tetPti_;
 
         //- Injector direction []
         vector direction_;
@@ -244,7 +244,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.C
index eb93b942d993d4eab82a0e90845ea61ad0dbcef9..94c25b01c8ed80efacf661e5159c5b5e6da7e8ad 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.C
@@ -201,13 +201,13 @@ void Foam::FieldActivatedInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     position = positions_[parcelI];
     cellOwner = injectorCells_[parcelI];
     tetFacei = injectorTetFaces_[parcelI];
-    tetPtI = injectorTetPts_[parcelI];
+    tetPti = injectorTetPts_[parcelI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.H
index c55ebc829b61cc12442a4149c799a2f40521a428..859745806291080486ac8900d743893829ccc92c 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/FieldActivatedInjection/FieldActivatedInjection.H
@@ -174,7 +174,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.C
index 8951c6c65368bc4e9706533baa95f490b8d992c4..ca0ac40eba36734fafa3892d29b188cb60f8e49e 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.C
@@ -446,7 +446,7 @@ void Foam::InflationInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     position = newParticles_[parcelI].first().first();
@@ -455,7 +455,7 @@ void Foam::InflationInjection<CloudType>::setPositionAndCell
     (
         cellOwner,
         tetFacei,
-        tetPtI,
+        tetPti,
         position,
         false
     );
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.H
index 7f0bc21c2e6fc983fc5965f4da96462342a4834c..e2248282d58d893bd8ca8a7c6d7d18ca2d42e422 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InflationInjection/InflationInjection.H
@@ -170,7 +170,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.C
index 77c18d476e4e5be58032f0300ad351c2a170a094..3042707ca6712eb008bca7567e88c3c29063ba99 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.C
@@ -73,7 +73,7 @@ bool Foam::InjectionModel<CloudType>::prepareForNextTimeStep
         }
         else
         {
-            // injection should have started, but not sufficient volume to
+            // Injection should have started, but not sufficient volume to
             // produce (at least) 1 parcel - hold value of timeStep0_
             validInjection = false;
         }
@@ -93,7 +93,7 @@ bool Foam::InjectionModel<CloudType>::findCellAtPosition
 (
     label& celli,
     label& tetFacei,
-    label& tetPtI,
+    label& tetPti,
     vector& position,
     bool errorOnNotFound
 )
@@ -107,7 +107,7 @@ bool Foam::InjectionModel<CloudType>::findCellAtPosition
         position,
         celli,
         tetFacei,
-        tetPtI
+        tetPti
     );
 
     label proci = -1;
@@ -125,7 +125,7 @@ bool Foam::InjectionModel<CloudType>::findCellAtPosition
     {
         celli = -1;
         tetFacei = -1;
-        tetPtI = -1;
+        tetPti = -1;
     }
 
     // Last chance - find nearest cell and try that one - the point is
@@ -138,7 +138,15 @@ bool Foam::InjectionModel<CloudType>::findCellAtPosition
         {
             position += SMALL*(cellCentres[celli] - position);
 
-            if (this->owner().mesh().pointInCell(position, celli))
+            this->owner().mesh().findCellFacePt
+            (
+                position,
+                celli,
+                tetFacei,
+                tetPti
+            );
+
+            if (celli > 0)
             {
                 proci = Pstream::myProcNo();
             }
@@ -150,7 +158,7 @@ bool Foam::InjectionModel<CloudType>::findCellAtPosition
         {
             celli = -1;
             tetFacei = -1;
-            tetPtI = -1;
+            tetPti = -1;
         }
     }
 
@@ -377,9 +385,7 @@ Foam::InjectionModel<CloudType>::~InjectionModel()
 
 template<class CloudType>
 void Foam::InjectionModel<CloudType>::updateMesh()
-{
-    // do nothing
-}
+{}
 
 
 template<class CloudType>
@@ -443,7 +449,7 @@ void Foam::InjectionModel<CloudType>::inject(TrackData& td)
                 // tetFace and tetPt
                 label celli = -1;
                 label tetFacei = -1;
-                label tetPtI = -1;
+                label tetPti = -1;
 
                 vector pos = Zero;
 
@@ -455,7 +461,7 @@ void Foam::InjectionModel<CloudType>::inject(TrackData& td)
                     pos,
                     celli,
                     tetFacei,
-                    tetPtI
+                    tetPti
                 );
 
                 if (celli > -1)
@@ -468,7 +474,7 @@ void Foam::InjectionModel<CloudType>::inject(TrackData& td)
 
                     // Create a new parcel
                     parcelType* pPtr =
-                        new parcelType(mesh, pos, celli, tetFacei, tetPtI);
+                        new parcelType(mesh, pos, celli, tetFacei, tetPti);
 
                     // Check/set new parcel thermo properties
                     cloud.setParcelThermoProperties(*pPtr, dt);
@@ -563,7 +569,7 @@ void Foam::InjectionModel<CloudType>::injectSteadyState
         // tetFace and tetPt
         label celli = -1;
         label tetFacei = -1;
-        label tetPtI = -1;
+        label tetPti = -1;
 
         vector pos = Zero;
 
@@ -575,7 +581,7 @@ void Foam::InjectionModel<CloudType>::injectSteadyState
             pos,
             celli,
             tetFacei,
-            tetPtI
+            tetPti
         );
 
         if (celli > -1)
@@ -585,7 +591,7 @@ void Foam::InjectionModel<CloudType>::injectSteadyState
 
             // Create a new parcel
             parcelType* pPtr =
-                new parcelType(mesh, pos, celli, tetFacei, tetPtI);
+                new parcelType(mesh, pos, celli, tetFacei, tetPti);
 
             // Check/set new parcel thermo properties
             cloud.setParcelThermoProperties(*pPtr, 0.0);
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.H
index 9e219bca1015896bf6902b7243d3e9135ad08b52..e1901c69d7b357bfe1453fe4be7f54e8e981ea62 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/InjectionModel/InjectionModel.H
@@ -160,7 +160,7 @@ protected:
         (
             label& celli,
             label& tetFacei,
-            label& tetPtI,
+            label& tetPti,
             vector& position,
             bool errorOnNotFound = true
         );
@@ -320,7 +320,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             ) = 0;
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.C
index 3708cb89dc3cdd4c0875ed3b653a3ee2bba05dd6..d081be437ffdc24636306791221f333d7b813c43 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.C
@@ -176,7 +176,7 @@ void Foam::KinematicLookupTableInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     label injectorI = 0;
@@ -193,7 +193,7 @@ void Foam::KinematicLookupTableInjection<CloudType>::setPositionAndCell
     position = injectors_[injectorI].x();
     cellOwner = injectorCells_[injectorI];
     tetFacei = injectorTetFaces_[injectorI];
-    tetPtI = injectorTetPts_[injectorI];
+    tetPti = injectorTetPts_[injectorI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.H
index 622ac451c03e6be6189fe381947266e8c88acd8b..565a6b221a67358285bc1174792912b071a3195c 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/KinematicLookupTableInjection/KinematicLookupTableInjection.H
@@ -160,7 +160,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.C
index d19010de6f4ac9f7657c57a65f9869b82cb66af2..21fc2471f664367fbffa261e3049819e66bfba34 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.C
@@ -206,13 +206,13 @@ void Foam::ManualInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     position = positions_[parcelI];
     cellOwner = injectorCells_[parcelI];
     tetFacei = injectorTetFaces_[parcelI];
-    tetPtI = injectorTetPts_[parcelI];
+    tetPti = injectorTetPts_[parcelI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.H
index 01ecf0d5c6a2ffd8799f6ae5a89bdf94dd5f9ea6..d8789a964637b45c204f8b5bcc36aa9174abf672 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/ManualInjection/ManualInjection.H
@@ -151,7 +151,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/NoInjection/NoInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/NoInjection/NoInjection.H
index ae8a082ba9cfda9530a823b13e79164431c216b8..9aaf8793875900fec7ae03615b95b67b895be5bc 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/NoInjection/NoInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/NoInjection/NoInjection.H
@@ -106,7 +106,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             virtual void setProperties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.C
index 4703885b37aaa1b1bce6c5fdf2cf7d936be19102..01873a3091d0e9c177c01221dc8bb8e8f2dff161 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.C
@@ -221,7 +221,7 @@ void Foam::PatchFlowRateInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     patchInjectionBase::setPositionAndCell
@@ -231,7 +231,7 @@ void Foam::PatchFlowRateInjection<CloudType>::setPositionAndCell
         position,
         cellOwner,
         tetFacei,
-        tetPtI
+        tetPti
     );
 }
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.H
index df767d2fd66f344b0b1d69e2361dae4cff32515d..9df1aac0b99982049b7e2964ddee98a13bfdfd35 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchFlowRateInjection/PatchFlowRateInjection.H
@@ -157,7 +157,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             virtual void setProperties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.C
index ef10b640cf92a18ba9aefd364ed932380eee7e7a..b73c4c0d749cd9568934e13debc6a90f95afb9ce 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.C
@@ -176,7 +176,7 @@ void Foam::PatchInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     patchInjectionBase::setPositionAndCell
@@ -186,7 +186,7 @@ void Foam::PatchInjection<CloudType>::setPositionAndCell
         position,
         cellOwner,
         tetFacei,
-        tetPtI
+        tetPti
     );
 }
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.H
index b1c0825ecf833af6a5a45992543f3e6847c48370..61ce2c971db5be6312a351114b5fc8ee14272e3e 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/PatchInjection.H
@@ -152,7 +152,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             virtual void setProperties
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.C b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.C
index a83812ab010aa384bd2b6b230841a68863cdd526..082c2a732738c6a8bcb0c4f4f26fa0828848af1a 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.C
@@ -153,7 +153,7 @@ void Foam::patchInjectionBase::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     scalar areaFraction = rnd.globalPosition(scalar(0), patchArea_);
@@ -209,13 +209,13 @@ void Foam::patchInjectionBase::setPositionAndCell
             // the base point on the face as the tetPt.  The tracking will pick
             // the cell consistent with the motion in the first tracking step
             tetFacei = mesh.cells()[cellOwner][0];
-            tetPtI = 1;
+            tetPti = 1;
         }
         else
         {
             cellOwner = -1;
             tetFacei = -1;
-            tetPtI = -1;
+            tetPti = -1;
 
             // Dummy position
             position = pTraits<vector>::max;
@@ -225,7 +225,7 @@ void Foam::patchInjectionBase::setPositionAndCell
     {
         cellOwner = -1;
         tetFacei = -1;
-        tetPtI = -1;
+        tetPti = -1;
 
         // Dummy position
         position = pTraits<vector>::max;
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.H b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.H
index e6fdd27c9c818815a2ab08d71960eb5ea7c2d277..47c003b60b796a07633f0cc5c8c3962e336e54e7 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.H
+++ b/src/lagrangian/intermediate/submodels/Kinematic/InjectionModel/PatchInjection/patchInjectionBase.H
@@ -121,7 +121,7 @@ public:
             vector& position,
             label& cellOwner,
             label& tetFacei,
-            label& tetPtI
+            label& tetPti
         );
 };
 
diff --git a/src/lagrangian/intermediate/submodels/Kinematic/SurfaceFilmModel/SurfaceFilmModel/SurfaceFilmModel.C b/src/lagrangian/intermediate/submodels/Kinematic/SurfaceFilmModel/SurfaceFilmModel/SurfaceFilmModel.C
index d7be65546ce4eb4c4a31104c91ba498d3557825d..c5016097725856a7be40fb06a0a72f7459a7b789 100644
--- a/src/lagrangian/intermediate/submodels/Kinematic/SurfaceFilmModel/SurfaceFilmModel/SurfaceFilmModel.C
+++ b/src/lagrangian/intermediate/submodels/Kinematic/SurfaceFilmModel/SurfaceFilmModel/SurfaceFilmModel.C
@@ -152,7 +152,7 @@ void Foam::SurfaceFilmModel<CloudType>::inject(TrackData& td)
                 // point as the tetPt.  The tracking will pick the cell
                 // consistent with the motion in the first tracking step.
                 const label tetFacei = this->owner().mesh().cells()[celli][0];
-                const label tetPtI = 1;
+                const label tetPti = 1;
 
 //                const point& pos = this->owner().mesh().C()[celli];
 
@@ -172,7 +172,7 @@ void Foam::SurfaceFilmModel<CloudType>::inject(TrackData& td)
                         pos,
                         celli,
                         tetFacei,
-                        tetPtI
+                        tetPti
                     );
 
                 // Check/set new parcel thermo properties
diff --git a/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.C b/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.C
index f0b33169cdbc25bfdb385751bb3adf8089fe5508..40290f9a851e5dfaec3799e65244a64e0fd56ace 100644
--- a/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.C
+++ b/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.C
@@ -175,7 +175,7 @@ void Foam::ReactingLookupTableInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     label injectorI = 0;
@@ -192,7 +192,7 @@ void Foam::ReactingLookupTableInjection<CloudType>::setPositionAndCell
     position = injectors_[injectorI].x();
     cellOwner = injectorCells_[injectorI];
     tetFacei = injectorTetFaces_[injectorI];
-    tetPtI = injectorTetPts_[injectorI];
+    tetPti = injectorTetPts_[injectorI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.H b/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.H
index 4d18307b48e523d11a6654b2c9a0317fe9163b9d..100046e5f8269ca6e5feb162979fe34c3e1a07b7 100644
--- a/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.H
+++ b/src/lagrangian/intermediate/submodels/Reacting/InjectionModel/ReactingLookupTableInjection/ReactingLookupTableInjection.H
@@ -160,7 +160,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.C b/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.C
index 9db4d1cd2d0b41789ec535595115992f0af89151..7361402d21bf4d4afef30f4e9a4cc4f1b03aa952 100644
--- a/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.C
+++ b/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.C
@@ -181,7 +181,7 @@ void Foam::ReactingMultiphaseLookupTableInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     label injectorI = 0;
@@ -198,7 +198,7 @@ void Foam::ReactingMultiphaseLookupTableInjection<CloudType>::setPositionAndCell
     position = injectors_[injectorI].x();
     cellOwner = injectorCells_[injectorI];
     tetFacei = injectorTetFaces_[injectorI];
-    tetPtI = injectorTetPts_[injectorI];
+    tetPti = injectorTetPts_[injectorI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.H b/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.H
index 9a01e6314cb70c6bf8c140ea19f9a0e1c92e3d51..36276e54872bca734bda995999db64625caccc5c 100644
--- a/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.H
+++ b/src/lagrangian/intermediate/submodels/ReactingMultiphase/InjectionModel/ReactingMultiphaseLookupTableInjection/ReactingMultiphaseLookupTableInjection.H
@@ -162,7 +162,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.C b/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.C
index 35e14f2682ea67c4a7f73c618963b3f5413057f1..b93166d4d4ad57a6695ccc5fdb6242dfb69a770a 100644
--- a/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.C
+++ b/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.C
@@ -176,7 +176,7 @@ void Foam::ThermoLookupTableInjection<CloudType>::setPositionAndCell
     vector& position,
     label& cellOwner,
     label& tetFacei,
-    label& tetPtI
+    label& tetPti
 )
 {
     label injectorI = 0;
@@ -193,7 +193,7 @@ void Foam::ThermoLookupTableInjection<CloudType>::setPositionAndCell
     position = injectors_[injectorI].x();
     cellOwner = injectorCells_[injectorI];
     tetFacei = injectorTetFaces_[injectorI];
-    tetPtI = injectorTetPts_[injectorI];
+    tetPti = injectorTetPts_[injectorI];
 }
 
 
diff --git a/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.H b/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.H
index 4fb4b10dcdea4d5cd63172229f9e50635a2f00bc..bb68a49ff4fa30f5fb6c6f73dbbba76b99f5ba97 100644
--- a/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.H
+++ b/src/lagrangian/intermediate/submodels/Thermodynamic/InjectionModel/ThermoLookupTableInjection/ThermoLookupTableInjection.H
@@ -160,7 +160,7 @@ public:
                 vector& position,
                 label& cellOwner,
                 label& tetFacei,
-                label& tetPtI
+                label& tetPti
             );
 
             //- Set the parcel properties
diff --git a/src/lagrangian/molecularDynamics/molecule/molecule/molecule.H b/src/lagrangian/molecularDynamics/molecule/molecule/molecule.H
index a54c874495298650474e3556c0b57e791c34d196..d2e38e5c296ede93574e03c118b6def27db6f570 100644
--- a/src/lagrangian/molecularDynamics/molecule/molecule/molecule.H
+++ b/src/lagrangian/molecularDynamics/molecule/molecule/molecule.H
@@ -242,7 +242,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const tensor& Q,
             const vector& v,
             const vector& a,
diff --git a/src/lagrangian/molecularDynamics/molecule/molecule/moleculeI.H b/src/lagrangian/molecularDynamics/molecule/molecule/moleculeI.H
index c9c4077949a2a9709c9ff7917521e6358024de35..5c3058d0d4ebc0c373d1996f7bbbde44003f1dfa 100644
--- a/src/lagrangian/molecularDynamics/molecule/molecule/moleculeI.H
+++ b/src/lagrangian/molecularDynamics/molecule/molecule/moleculeI.H
@@ -223,7 +223,7 @@ inline Foam::molecule::molecule
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const tensor& Q,
     const vector& v,
     const vector& a,
@@ -236,7 +236,7 @@ inline Foam::molecule::molecule
 
 )
 :
-    particle(mesh, position, celli, tetFacei, tetPtI),
+    particle(mesh, position, celli, tetFacei, tetPti),
     Q_(Q),
     v_(v),
     a_(a),
diff --git a/src/lagrangian/solidParticle/solidParticle.H b/src/lagrangian/solidParticle/solidParticle.H
index 72af01cf281ddd04eace1ef8742330db85af5778..1a0258a48fd6ef8bdce428f0e2815263a8d26462 100644
--- a/src/lagrangian/solidParticle/solidParticle.H
+++ b/src/lagrangian/solidParticle/solidParticle.H
@@ -133,7 +133,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const scalar d,
             const vector& U
         );
diff --git a/src/lagrangian/solidParticle/solidParticleI.H b/src/lagrangian/solidParticle/solidParticleI.H
index f1074b7298ba7447c359e609a054b6487d1ddece..c1b6fdd4189f49f70abdb164686623af43edeb9b 100644
--- a/src/lagrangian/solidParticle/solidParticleI.H
+++ b/src/lagrangian/solidParticle/solidParticleI.H
@@ -48,12 +48,12 @@ inline Foam::solidParticle::solidParticle
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const scalar d,
     const vector& U
 )
 :
-    particle(mesh, position, celli, tetFacei, tetPtI),
+    particle(mesh, position, celli, tetFacei, tetPti),
     d_(d),
     U_(U)
 {}
diff --git a/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcel.H b/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcel.H
index 056c2b666903d9c0112821a5826bf7ed0d09d88f..4f3c62469012557506762bfb391033a3d1476cad 100644
--- a/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcel.H
+++ b/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcel.H
@@ -192,7 +192,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components
@@ -202,7 +202,7 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const label typeId,
             const scalar nParticle0,
             const scalar d0,
diff --git a/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcelI.H b/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcelI.H
index 526341eaf2ec03a77f39a6c673b28dab786a4c6e..d0f7391b8269e02ff027888542a57f60e42bd280 100644
--- a/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcelI.H
+++ b/src/lagrangian/spray/parcels/Templates/SprayParcel/SprayParcelI.H
@@ -110,10 +110,10 @@ inline Foam::SprayParcel<ParcelType>::SprayParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI
+    const label tetPti
 )
 :
-    ParcelType(mesh, position, celli, tetFacei, tetPtI),
+    ParcelType(mesh, position, celli, tetFacei, tetPti),
     d0_(this->d()),
     position0_(position),
     sigma_(0.0),
@@ -137,7 +137,7 @@ inline Foam::SprayParcel<ParcelType>::SprayParcel
     const vector& position,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const label typeId,
     const scalar nParticle0,
     const scalar d0,
@@ -165,7 +165,7 @@ inline Foam::SprayParcel<ParcelType>::SprayParcel
         position,
         celli,
         tetFacei,
-        tetPtI,
+        tetPti,
         typeId,
         nParticle0,
         d0,
diff --git a/src/functionObjects/field/wallBoundedStreamLine/wallBoundedParticleTemplates.C b/src/functionObjects/field/wallBoundedStreamLine/wallBoundedParticleTemplates.C
index ddbe21109a72d8429c6a9d4f3a28f4e4361bc53d..7ee23cac58de22d33e535a47b3b8ae6445fc73a6 100644
--- a/src/functionObjects/field/wallBoundedStreamLine/wallBoundedParticleTemplates.C
+++ b/src/functionObjects/field/wallBoundedStreamLine/wallBoundedParticleTemplates.C
@@ -34,7 +34,6 @@ void Foam::wallBoundedParticle::patchInteraction
     const scalar trackFraction
 )
 {
-//    typedef TrackData::CloudType cloudType;
     typedef typename TrackData::cloudType::particleType particleType;
 
     particleType& p = static_cast<particleType&>(*this);
@@ -45,7 +44,7 @@ void Foam::wallBoundedParticle::patchInteraction
         label origFacei = facei_;
         label patchi = patch(facei_);
 
         // No action taken for tetPtI_ for tetFacei_ here, handled by
         // patch interaction call or later during processor transfer.
 
 
@@ -175,7 +174,7 @@ Foam::scalar Foam::wallBoundedParticle::trackToEdge
             // Check angle to nbrCell tet. Is it in the direction of the
             // endposition? I.e. since volume of nbr tet is positive the
             // tracking direction should be into the tet.
-            tetIndices nbrTi(nbrCelli, tetFacei_, tetPtI_, mesh_);
+            tetIndices nbrTi(nbrCelli, tetFacei_, tetPti_, mesh_);
             if ((nbrTi.faceTri(mesh_).normal() & (endPosition-position())) < 0)
             {
                 // Change into nbrCell. No need to change tetFace, tetPt.
@@ -45,7 +44,7 @@ void Foam::wallBoundedParticle::patchInteraction
         label patchi = patch(facei_);
 
-        // No action taken for tetPtI_ for tetFacei_ here, handled by
+        // No action taken for tetPti_ for tetFacei_ here, handled by
         // patch interaction call or later during processor transfer.
 
diff --git a/src/lagrangian/basic/particle/particle.H b/src/lagrangian/basic/particle/particle.H
index d6f1855edbdbbb0bdb055232fe8d25c98bf9cff1..7da868fa2f3b21353a81818c77e2d83b5979d677 100644
--- a/src/lagrangian/basic/particle/particle.H
+++ b/src/lagrangian/basic/particle/particle.H
@@ -156,7 +156,7 @@ protected:
         //- Index of the point on the face that defines the decomposed
         //  tet that the particle is in.  Relative to the face base
         //  point.
-        label tetPtI_;
+        label tetPti_;
 
         //- Originating processor id
         label origProc_;
@@ -189,7 +189,7 @@ protected:
             const label tetPlaneBasePtI,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const scalar tol
         ) const;
 
@@ -203,7 +203,7 @@ protected:
             const label tetPlaneBasePtI,
             const label celli,
             const label tetFacei,
-            const label tetPtI,
+            const label tetPti,
             const scalar tol
         ) const;
 
@@ -211,12 +211,12 @@ protected:
         inline void tetNeighbour(label triI);
 
         //- Cross the from the given face across the given edge of the
         //  given cell to find the resulting face and tetPtI
         inline void crossEdgeConnectedFace
         (
             const label& celli,
             label& tetFacei,
-            label& tetPtI,
+            label& tetPti,
             const edge& e
         );
 
@@ -316,7 +316,7 @@ public:
         DefinePropertyList
         (
             "(Px Py Pz) celli facei stepFraction "
-            "tetFacei tetPtI origProc origId"
+            "tetFacei tetPti origProc origId"
         );
 
         //- Cumulative particle counter - used to provode unique ID
@@ -343,10 +343,10 @@ public:
             const vector& position,
             const label celli,
             const label tetFacei,
-            const label tetPtI
+            const label tetPti
         );
 
         //- Construct from components, tetFacei_ and tetPtI_ are not
         //  supplied so they will be deduced by a search
         particle
         (
@@ -211,12 +211,12 @@ protected:
 
         //- Cross the from the given face across the given edge of the
-        //  given cell to find the resulting face and tetPtI
+        //  given cell to find the resulting face and tetPti
         inline void crossEdgeConnectedFace
         (
@@ -343,10 +343,10 @@ public:
         );
 
-        //- Construct from components, tetFacei_ and tetPtI_ are not
+        //- Construct from components, tetFacei_ and tetPti_ are not
         //  supplied so they will be deduced by a search
         particle
diff --git a/src/lagrangian/basic/particle/particleI.H b/src/lagrangian/basic/particle/particleI.H
index a31aadd57ede8c0e76f6cfae2e68b4609c67b4df..5df1a22e92ee6ae41534e79015e7a19870556a89 100644
--- a/src/lagrangian/basic/particle/particleI.H
+++ b/src/lagrangian/basic/particle/particleI.H
@@ -53,7 +53,7 @@ inline void Foam::particle::findTris
             tetPlaneBasePtIs[i],
             celli_,
             tetFacei_,
-            tetPtI_,
+            tetPti_,
             tol
         );
 
@@ -74,7 +74,7 @@ inline Foam::scalar Foam::particle::tetLambda
     const label tetPlaneBasePtI,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const scalar tol
 ) const
 {
@@ -91,7 +91,7 @@ inline Foam::scalar Foam::particle::tetLambda
             tetPlaneBasePtI,
             celli,
             tetFacei,
-            tetPtI,
+            tetPti,
             tol
         );
     }
@@ -146,7 +146,7 @@ inline Foam::scalar Foam::particle::movingTetLambda
     const label tetPlaneBasePtI,
     const label celli,
     const label tetFacei,
-    const label tetPtI,
+    const label tetPti,
     const scalar tol
 ) const
 {
@@ -169,7 +169,7 @@ inline Foam::scalar Foam::particle::movingTetLambda
     vector n0 = Zero;
 
     {
-        tetIndices tetIs(celli, tetFacei, tetPtI, mesh_);
+        tetIndices tetIs(celli, tetFacei, tetPti, mesh_);
 
         // Tet at timestep start
         tetPointRef tet00 = tetIs.oldTet(mesh_);
@@ -337,7 +337,7 @@ inline void Foam::particle::tetNeighbour(label triI)
             << abort(FatalError);
     }
 
-    label facePtI = (tetPtI_ + tetBasePtI) % f.size();
+    label facePtI = (tetPti_ + tetBasePtI) % f.size();
     label otherFacePtI = f.fcIndex(facePtI);
 
     switch (triI)
@@ -348,7 +348,7 @@ inline void Foam::particle::tetNeighbour(label triI)
             // neighbour cell over tetFacei
 
             // Modification of celli_ will happen by other indexing,
             // tetFacei_ and tetPtI don't change.
 
             break;
         }
@@ -358,7 +358,7 @@ inline void Foam::particle::tetNeighbour(label triI)
             (
                 celli_,
                 tetFacei_,
-                tetPtI_,
+                tetPti_,
                 Foam::edge(f[facePtI], f[otherFacePtI])
             );
 
@@ -368,9 +368,9 @@ inline void Foam::particle::tetNeighbour(label triI)
         {
             if (own)
             {
-                if (tetPtI_ < f.size() - 2)
+                if (tetPti_ < f.size() - 2)
                 {
-                    tetPtI_ = f.fcIndex(tetPtI_);
+                    tetPti_ = f.fcIndex(tetPti_);
                 }
                 else
                 {
@@ -378,16 +378,16 @@ inline void Foam::particle::tetNeighbour(label triI)
                     (
                         celli_,
                         tetFacei_,
-                        tetPtI_,
+                        tetPti_,
                         Foam::edge(f[tetBasePtI], f[otherFacePtI])
                     );
                 }
             }
             else
             {
-                if (tetPtI_ > 1)
+                if (tetPti_ > 1)
                 {
-                    tetPtI_ = f.rcIndex(tetPtI_);
+                    tetPti_ = f.rcIndex(tetPti_);
                 }
                 else
                 {
@@ -395,7 +395,7 @@ inline void Foam::particle::tetNeighbour(label triI)
                     (
                         celli_,
                         tetFacei_,
-                        tetPtI_,
+                        tetPti_,
                         Foam::edge(f[tetBasePtI], f[facePtI])
                     );
                 }
@@ -407,9 +407,9 @@ inline void Foam::particle::tetNeighbour(label triI)
         {
             if (own)
             {
-                if (tetPtI_ > 1)
+                if (tetPti_ > 1)
                 {
-                    tetPtI_ = f.rcIndex(tetPtI_);
+                    tetPti_ = f.rcIndex(tetPti_);
                 }
                 else
                 {
@@ -417,16 +417,16 @@ inline void Foam::particle::tetNeighbour(label triI)
                     (
                         celli_,
                         tetFacei_,
-                        tetPtI_,
+                        tetPti_,
                         Foam::edge(f[tetBasePtI], f[facePtI])
                     );
                 }
             }
             else
             {
-                if (tetPtI_ < f.size() - 2)
+                if (tetPti_ < f.size() - 2)
                 {
-                    tetPtI_ = f.fcIndex(tetPtI_);
+                    tetPti_ = f.fcIndex(tetPti_);
                 }
                 else
                 {
@@ -434,7 +434,7 @@ inline void Foam::particle::tetNeighbour(label triI)
                     (
                         celli_,
                         tetFacei_,
-                        tetPtI_,
+                        tetPti_,
                         Foam::edge(f[tetBasePtI], f[otherFacePtI])
                     );
                 }
@@ -458,7 +458,7 @@ inline void Foam::particle::crossEdgeConnectedFace
 (
     const label& celli,
     label& tetFacei,
-    label& tetPtI,
+    label& tetPti,
     const edge& e
 )
 {
@@ -542,17 +542,17 @@ inline void Foam::particle::crossEdgeConnectedFace
             {
                 // The point is the base point, so this is first tet
                 // in the face circulation
-                tetPtI = 1;
+                tetPti = 1;
             }
             else if (eIndex == otherFace.size() - 1)
             {
                 // The point is the last before the base point, so
                 // this is the last tet in the face circulation
-                tetPtI = otherFace.size() - 2;
+                tetPti = otherFace.size() - 2;
             }
             else
             {
-                tetPtI = eIndex;
+                tetPti = eIndex;
             }
 
             break;
@@ -621,19 +621,19 @@ inline Foam::label& Foam::particle::tetFace()
 
 inline Foam::label Foam::particle::tetPt() const
 {
-    return tetPtI_;
+    return tetPti_;
 }
 
 
 inline Foam::label& Foam::particle::tetPt()
 {
-    return tetPtI_;
+    return tetPti_;
 }
 
 
 inline Foam::tetIndices Foam::particle::currentTetIndices() const
 {
-    return tetIndices(celli_, tetFacei_, tetPtI_, mesh_);
+    return tetIndices(celli_, tetFacei_, tetPti_, mesh_);
 }
 
 
@@ -676,21 +676,22 @@ inline void Foam::particle::initCellFacePt()
             position_,
             celli_,
             tetFacei_,
-            tetPtI_
+            tetPti_
         );
 
-        if (celli_ == -1)
+        if (debug && celli_ == -1)
         {
-            FatalErrorInFunction
-                << "cell, tetFace and tetPt search failure at position "
-                << position_ << abort(FatalError);
+            WarningInFunction
+                << "cell, tetFace and tetPt search failure for position "
+                << position_
+                << endl;
         }
     }
     else
     {
-        mesh_.findTetFacePt(celli_, position_, tetFacei_, tetPtI_);
+        mesh_.findTetFacePt(celli_, position_, tetFacei_, tetPti_);
 
-        if (tetFacei_ == -1 || tetPtI_ == -1)
+        if (tetFacei_ == -1 || tetPti_ == -1)
         {
             label oldCelli = celli_;
 
@@ -699,43 +700,45 @@ inline void Foam::particle::initCellFacePt()
                 position_,
                 celli_,
                 tetFacei_,
-                tetPtI_
+                tetPti_
             );
 
-            if (celli_ == -1 || tetFacei_ == -1 || tetPtI_ == -1)
+            if (celli_ == -1 || tetFacei_ == -1 || tetPti_ == -1)
             {
-                // The particle has entered this function with a cell
-                // number, but hasn't been able to find a cell to
-                // occupy.
+                // The particle has entered this function with a cell number,
+                // but hasn't been able to find a cell to occupy.
 
                 if (!mesh_.pointInCellBB(position_, oldCelli, 0.1))
                 {
-                    // If the position is not inside the (slightly
-                    // extended) bound-box of the cell that it thought
-                    // it should be in, then this is considered an
-                    // error.
-
-                    FatalErrorInFunction
-                        << "position " << position_ << nl
-                        << "    for requested cell " << oldCelli << nl
-                        << "    If this is a restart or "
-                           "reconstruction/decomposition etc. it is likely that"
-                           " the write precision is not sufficient.\n"
-                           "    Either increase 'writePrecision' or "
-                           "set 'writeFormat' to 'binary'"
-                        << abort(FatalError);
+                    // If the position is not inside the (slightly extended)
+                    // bound-box of the cell that it thought it should be in,
+                    // then this is considered an error.
+
+                    if (debug)
+                    {
+                        WarningInFunction
+                            << "position " << position_
+                            << " not in specified cell " << oldCelli
+                            << " with centre " << mesh_.cellCentres()[oldCelli]
+                            << endl;
+                    }
+
+                    celli_ = -1;
+                    tetFacei_ = -1;
+                    tetPti_ = -1;
+
+                    return;
                 }
 
-                // The position is in the (slightly extended)
-                // bound-box of the cell.  This situation may arise
-                // because the face decomposition of the cell is not
-                // the same as when the particle acquired the cell
-                // index.  For example, it has been read into a mesh
-                // that has made a different face base-point decision
-                // for a boundary face and now this particle is in a
-                // position that is not in the mesh.  Gradually move
-                // the particle towards the centre of the cell that it
-                // thought that it was in.
+                // The position is in the (slightly extended) bound-box of the
+                // cell.  This situation may arise because the face
+                // decomposition of the cell is not the same as when the
+                // particle acquired the cell index.  For example, it has been
+                // read into a mesh that has made a different face base-point
+                // decision for a boundary face and now this particle is in a
+                // position that is not in the mesh.  Gradually move the
+                // particle towards the centre of the cell that it thought that
+                // it was in.
 
                 celli_ = oldCelli;
 
@@ -756,7 +759,7 @@ inline void Foam::particle::initCellFacePt()
                         celli_,
                         newPosition,
                         tetFacei_,
-                        tetPtI_
+                        tetPti_
                     );
 
                     iterNo++;
@@ -777,7 +780,7 @@ inline void Foam::particle::initCellFacePt()
                         << " to " << newPosition
                         << " in cell " << celli_
                         << " tetFace " << tetFacei_
-                        << " tetPt " << tetPtI_ << nl
+                        << " tetPt " << tetPti_ << nl
                         << "    (A fraction of "
                         << 1.0 - mag(cC - newPosition)/mag(cC - position_)
                         << " of the distance to the cell centre)"
@@ -797,7 +800,7 @@ inline void Foam::particle::initCellFacePt()
                     << "    Found"
                     << " cell " << celli_
                     << " tetFace " << tetFacei_
-                    << " tetPt " << tetPtI_ << nl
+                    << " tetPt " << tetPti_ << nl
                     << "    This is a different cell to that which was supplied"
                     << " (" << oldCelli << ")." << nl
                     << endl;
@@ -348,7 +348,7 @@ inline void Foam::particle::tetNeighbour(label triI)
 
             // Modification of celli_ will happen by other indexing,
-            // tetFacei_ and tetPtI don't change.
+            // tetFacei_ and tetPti don't change.
 
             break;
diff --git a/src/lagrangian/basic/particle/particleTemplates.C b/src/lagrangian/basic/particle/particleTemplates.C
index 876f765debda85b1e2181b7e084b045dfc43e3c4..15e1340a2711b3a0a86d690cb58a88c3fff32ee8 100644
--- a/src/lagrangian/basic/particle/particleTemplates.C
+++ b/src/lagrangian/basic/particle/particleTemplates.C
@@ -88,7 +88,7 @@ void Foam::particle::correctAfterParallelTransfer
     tetFacei_ = facei_ + ppp.start();
 
     // Faces either side of a coupled patch have matched base indices,
     // tetPtI is specified relative to the base point, already and
     // opposite circulation directions by design, so if the vertices
     // are:
     // source:
@@ -108,7 +108,7 @@ void Foam::particle::correctAfterParallelTransfer
     // This relationship can be verified for other points and sizes of
     // face.
 
-    tetPtI_ = mesh_.faces()[tetFacei_].size() - 1 - tetPtI_;
+    tetPti_ = mesh_.faces()[tetFacei_].size() - 1 - tetPti_;
 
     // Reset the face index for the next tracking operation
     if (stepFraction_ > (1.0 - SMALL))
@@ -226,7 +226,7 @@ Foam::scalar Foam::particle::trackToFace
     // Pout<< "stepFraction " << stepFraction_ << nl
     //     << "celli " << celli_ << nl
     //     << "tetFacei " << tetFacei_ << nl
-    //     << "tetPtI " << tetPtI_
+    //     << "tetPti " << tetPti_
     //     << endl;
 
     scalar trackFraction = 0.0;
@@ -245,10 +245,10 @@ Foam::scalar Foam::particle::trackToFace
     //   + pA and pB are the remaining points on the face, such that
     //     the circulation, {basePt, pA, pB} produces a positive
     //     normal by the right-hand rule.  pA and pB are chosen from
     //     tetPtI_ do accomplish this depending if the cell owns the
     //     face, tetPtI_ is the vertex that characterises the tet, and
     //     is the first vertex on the tet when circulating around the
     //     face. Therefore, the same tetPtI represents the same face
     //     triangle for both the owner and neighbour cell.
     //
     // Each tet has its four triangles represented in the same order:
@@ -309,7 +309,7 @@ Foam::scalar Foam::particle::trackToFace
 
         label basePtI = f[tetBasePtI];
 
-        label facePtI = (tetPtI_ + tetBasePtI) % f.size();
+        label facePtI = (tetPti_ + tetBasePtI) % f.size();
         label otherFacePtI = f.fcIndex(facePtI);
 
         label fPtAI = -1;
@@ -430,7 +430,7 @@ Foam::scalar Foam::particle::trackToFace
                     tetPlaneBasePtIs[tI],
                     celli_,
                     tetFacei_,
-                    tetPtI_,
+                    tetPti_,
                     lambdaDistanceTolerance
                 );
 
@@ -457,7 +457,7 @@ Foam::scalar Foam::particle::trackToFace
                 tetBasePtI,
                 fPtAI,
                 fPtBI,
-                tetPtI_
+                tetPti_
             );
         }
         else if (triI > 0)
@@ -470,7 +470,7 @@ Foam::scalar Foam::particle::trackToFace
         //     << "    " << celli_
         //     << "    " << facei_
         //     << " " << tetFacei_
-        //     << " " << tetPtI_
+        //     << " " << tetPti_
         //     << " " << triI
         //     << " " << lambdaMin
         //     << " " << trackFraction
@@ -479,7 +479,7 @@ Foam::scalar Foam::particle::trackToFace
         // Pout<< "# Tracking loop tet "
         //     << origId_ << " " << origProc_<< nl
         //     << "# face: " << tetFacei_ << nl
-        //     << "# tetPtI: " << tetPtI_ << nl
+        //     << "# tetPti: " << tetPti_ << nl
         //     << "# tetBasePtI: " << mesh_.tetBasePtIs()[tetFacei_] << nl
         //     << "# tet.mag(): " << tet.mag() << nl
         //     << "# tet.quality(): " << tet.quality()
@@ -555,7 +555,7 @@ Foam::scalar Foam::particle::trackToFace
         label origFacei = facei_;
         label patchi = patch(facei_);
 
         // No action taken for tetPtI_ for tetFacei_ here, handled by
         // patch interaction call or later during processor transfer.
 
         if
@@ -1000,8 +1000,8 @@ void Foam::particle::hitCyclicPatch
 
     tetFacei_ = facei_;
 
-    // See note in correctAfterParallelTransfer for tetPtI_ addressing.
-    tetPtI_ = mesh_.faces()[tetFacei_].size() - 1 - tetPtI_;
+    // See note in correctAfterParallelTransfer for tetPti_ addressing.
+    tetPti_ = mesh_.faces()[tetFacei_].size() - 1 - tetPti_;
 
     const cyclicPolyPatch& receiveCpp = cpp.neighbPatch();
     label patchFacei = receiveCpp.whichFace(facei_);
@@ -1053,10 +1053,15 @@ void Foam::particle::hitCyclicAMIPatch
 
     if (patchFacei < 0)
     {
-        FatalErrorInFunction
+        // If the patch face of the particle is not known assume that
+        // the particle is lost and to be deleted
+        td.keepParticle = false;
+
+        WarningInFunction
             << "Particle lost across " << cyclicAMIPolyPatch::typeName
             << " patches " << cpp.name() << " and " << receiveCpp.name()
-            << " at position " << position_ << abort(FatalError);
+            << " at position " << position_
+            << endl;
     }
 
     // Convert face index into global numbering
@@ -1066,8 +1071,8 @@ void Foam::particle::hitCyclicAMIPatch
 
     tetFacei_ = facei_;
 
-    // See note in correctAfterParallelTransfer for tetPtI_ addressing.
-    tetPtI_ = mesh_.faces()[tetFacei_].size() - 1 - tetPtI_;
+    // See note in correctAfterParallelTransfer for tetPti_ addressing.
+    tetPti_ = mesh_.faces()[tetFacei_].size() - 1 - tetPti_;
 
     // Now the particle is on the receiving side
 
@@ -88,7 +88,7 @@ void Foam::particle::correctAfterParallelTransfer
 
     // Faces either side of a coupled patch have matched base indices,
-    // tetPtI is specified relative to the base point, already and
+    // tetPti is specified relative to the base point, already and
     // opposite circulation directions by design, so if the vertices
     // are:
@@ -245,10 +245,10 @@ Foam::scalar Foam::particle::trackToFace
     //     the circulation, {basePt, pA, pB} produces a positive
     //     normal by the right-hand rule.  pA and pB are chosen from
-    //     tetPtI_ do accomplish this depending if the cell owns the
-    //     face, tetPtI_ is the vertex that characterises the tet, and
+    //     tetPti_ do accomplish this depending if the cell owns the
+    //     face, tetPti_ is the vertex that characterises the tet, and
     //     is the first vertex on the tet when circulating around the
@@ -245,10 +245,10 @@ Foam::scalar Foam::particle::trackToFace
     //     is the first vertex on the tet when circulating around the
-    //     face. Therefore, the same tetPtI represents the same face
+    //     face. Therefore, the same tetPti represents the same face
     //     triangle for both the owner and neighbour cell.
     //
@@ -555,7 +555,7 @@ Foam::scalar Foam::particle::trackToFace
         label patchi = patch(facei_);
 
-        // No action taken for tetPtI_ for tetFacei_ here, handled by
+        // No action taken for tetPti_ for tetFacei_ here, handled by
         // patch interaction call or later during processor transfer.
 